# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreatePipelineDetails(object):
    """
    Properties used in pipeline create operations
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreatePipelineDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CreatePipelineDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreatePipelineDetails.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this CreatePipelineDetails.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this CreatePipelineDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreatePipelineDetails.
        :type description: str

        :param model_type:
            The value to assign to the model_type property of this CreatePipelineDetails.
        :type model_type: str

        :param object_version:
            The value to assign to the object_version property of this CreatePipelineDetails.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this CreatePipelineDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreatePipelineDetails.
        :type identifier: str

        :param nodes:
            The value to assign to the nodes property of this CreatePipelineDetails.
        :type nodes: list[oci.data_integration.models.FlowNode]

        :param parameters:
            The value to assign to the parameters property of this CreatePipelineDetails.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param flow_config_values:
            The value to assign to the flow_config_values property of this CreatePipelineDetails.
        :type flow_config_values: oci.data_integration.models.ConfigValues

        :param variables:
            The value to assign to the variables property of this CreatePipelineDetails.
        :type variables: list[oci.data_integration.models.Variable]

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreatePipelineDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'model_type': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'nodes': 'list[FlowNode]',
            'parameters': 'list[Parameter]',
            'flow_config_values': 'ConfigValues',
            'variables': 'list[Variable]',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'model_type': 'modelType',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'nodes': 'nodes',
            'parameters': 'parameters',
            'flow_config_values': 'flowConfigValues',
            'variables': 'variables',
            'registry_metadata': 'registryMetadata'
        }

        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._model_type = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._nodes = None
        self._parameters = None
        self._flow_config_values = None
        self._variables = None
        self._registry_metadata = None

    @property
    def key(self):
        """
        Gets the key of this CreatePipelineDetails.
        Generated key that can be used in API calls to identify pipeline. On scenarios where reference to the pipeline is needed, a value can be passed in create.


        :return: The key of this CreatePipelineDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CreatePipelineDetails.
        Generated key that can be used in API calls to identify pipeline. On scenarios where reference to the pipeline is needed, a value can be passed in create.


        :param key: The key of this CreatePipelineDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this CreatePipelineDetails.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :return: The model_version of this CreatePipelineDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreatePipelineDetails.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :param model_version: The model_version of this CreatePipelineDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this CreatePipelineDetails.

        :return: The parent_ref of this CreatePipelineDetails.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this CreatePipelineDetails.

        :param parent_ref: The parent_ref of this CreatePipelineDetails.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreatePipelineDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this CreatePipelineDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreatePipelineDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this CreatePipelineDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreatePipelineDetails.
        Detailed description for the object.


        :return: The description of this CreatePipelineDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreatePipelineDetails.
        Detailed description for the object.


        :param description: The description of this CreatePipelineDetails.
        :type: str
        """
        self._description = description

    @property
    def model_type(self):
        """
        Gets the model_type of this CreatePipelineDetails.
        The type of the object.


        :return: The model_type of this CreatePipelineDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this CreatePipelineDetails.
        The type of the object.


        :param model_type: The model_type of this CreatePipelineDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def object_version(self):
        """
        Gets the object_version of this CreatePipelineDetails.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :return: The object_version of this CreatePipelineDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this CreatePipelineDetails.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :param object_version: The object_version of this CreatePipelineDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this CreatePipelineDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this CreatePipelineDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this CreatePipelineDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this CreatePipelineDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this CreatePipelineDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this CreatePipelineDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this CreatePipelineDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this CreatePipelineDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def nodes(self):
        """
        Gets the nodes of this CreatePipelineDetails.
        A list of nodes attached to the pipeline


        :return: The nodes of this CreatePipelineDetails.
        :rtype: list[oci.data_integration.models.FlowNode]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """
        Sets the nodes of this CreatePipelineDetails.
        A list of nodes attached to the pipeline


        :param nodes: The nodes of this CreatePipelineDetails.
        :type: list[oci.data_integration.models.FlowNode]
        """
        self._nodes = nodes

    @property
    def parameters(self):
        """
        Gets the parameters of this CreatePipelineDetails.
        A list of additional parameters required in pipeline.


        :return: The parameters of this CreatePipelineDetails.
        :rtype: list[oci.data_integration.models.Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this CreatePipelineDetails.
        A list of additional parameters required in pipeline.


        :param parameters: The parameters of this CreatePipelineDetails.
        :type: list[oci.data_integration.models.Parameter]
        """
        self._parameters = parameters

    @property
    def flow_config_values(self):
        """
        Gets the flow_config_values of this CreatePipelineDetails.

        :return: The flow_config_values of this CreatePipelineDetails.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._flow_config_values

    @flow_config_values.setter
    def flow_config_values(self, flow_config_values):
        """
        Sets the flow_config_values of this CreatePipelineDetails.

        :param flow_config_values: The flow_config_values of this CreatePipelineDetails.
        :type: oci.data_integration.models.ConfigValues
        """
        self._flow_config_values = flow_config_values

    @property
    def variables(self):
        """
        Gets the variables of this CreatePipelineDetails.
        The list of variables required in pipeline.


        :return: The variables of this CreatePipelineDetails.
        :rtype: list[oci.data_integration.models.Variable]
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this CreatePipelineDetails.
        The list of variables required in pipeline.


        :param variables: The variables of this CreatePipelineDetails.
        :type: list[oci.data_integration.models.Variable]
        """
        self._variables = variables

    @property
    def registry_metadata(self):
        """
        **[Required]** Gets the registry_metadata of this CreatePipelineDetails.

        :return: The registry_metadata of this CreatePipelineDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this CreatePipelineDetails.

        :param registry_metadata: The registry_metadata of this CreatePipelineDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .field_map import FieldMap
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RuleBasedFieldMap(FieldMap):
    """
    A map of rule patterns.
    """

    #: A constant which can be used with the map_type property of a RuleBasedFieldMap.
    #: This constant has a value of "MAPBYNAME"
    MAP_TYPE_MAPBYNAME = "MAPBYNAME"

    #: A constant which can be used with the map_type property of a RuleBasedFieldMap.
    #: This constant has a value of "MAPBYPOSITION"
    MAP_TYPE_MAPBYPOSITION = "MAPBYPOSITION"

    #: A constant which can be used with the map_type property of a RuleBasedFieldMap.
    #: This constant has a value of "MAPBYPATTERN"
    MAP_TYPE_MAPBYPATTERN = "MAPBYPATTERN"

    def __init__(self, **kwargs):
        """
        Initializes a new RuleBasedFieldMap object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.RuleBasedFieldMap.model_type` attribute
        of this class is ``RULE_BASED_FIELD_MAP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this RuleBasedFieldMap.
            Allowed values for this property are: "DIRECT_NAMED_FIELD_MAP", "COMPOSITE_FIELD_MAP", "DIRECT_FIELD_MAP", "RULE_BASED_FIELD_MAP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param description:
            The value to assign to the description property of this RuleBasedFieldMap.
        :type description: str

        :param key:
            The value to assign to the key property of this RuleBasedFieldMap.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this RuleBasedFieldMap.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this RuleBasedFieldMap.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param config_values:
            The value to assign to the config_values property of this RuleBasedFieldMap.
        :type config_values: oci.data_integration.models.ConfigValues

        :param map_type:
            The value to assign to the map_type property of this RuleBasedFieldMap.
            Allowed values for this property are: "MAPBYNAME", "MAPBYPOSITION", "MAPBYPATTERN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type map_type: str

        :param from_pattern:
            The value to assign to the from_pattern property of this RuleBasedFieldMap.
        :type from_pattern: str

        :param to_pattern:
            The value to assign to the to_pattern property of this RuleBasedFieldMap.
        :type to_pattern: str

        :param is_java_regex_syntax:
            The value to assign to the is_java_regex_syntax property of this RuleBasedFieldMap.
        :type is_java_regex_syntax: bool

        :param object_status:
            The value to assign to the object_status property of this RuleBasedFieldMap.
        :type object_status: int

        :param from_rule_config:
            The value to assign to the from_rule_config property of this RuleBasedFieldMap.
        :type from_rule_config: oci.data_integration.models.RuleTypeConfig

        :param to_rule_config:
            The value to assign to the to_rule_config property of this RuleBasedFieldMap.
        :type to_rule_config: oci.data_integration.models.RuleTypeConfig

        """
        self.swagger_types = {
            'model_type': 'str',
            'description': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'config_values': 'ConfigValues',
            'map_type': 'str',
            'from_pattern': 'str',
            'to_pattern': 'str',
            'is_java_regex_syntax': 'bool',
            'object_status': 'int',
            'from_rule_config': 'RuleTypeConfig',
            'to_rule_config': 'RuleTypeConfig'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'description': 'description',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'config_values': 'configValues',
            'map_type': 'mapType',
            'from_pattern': 'fromPattern',
            'to_pattern': 'toPattern',
            'is_java_regex_syntax': 'isJavaRegexSyntax',
            'object_status': 'objectStatus',
            'from_rule_config': 'fromRuleConfig',
            'to_rule_config': 'toRuleConfig'
        }

        self._model_type = None
        self._description = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._config_values = None
        self._map_type = None
        self._from_pattern = None
        self._to_pattern = None
        self._is_java_regex_syntax = None
        self._object_status = None
        self._from_rule_config = None
        self._to_rule_config = None
        self._model_type = 'RULE_BASED_FIELD_MAP'

    @property
    def key(self):
        """
        Gets the key of this RuleBasedFieldMap.
        The object key.


        :return: The key of this RuleBasedFieldMap.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this RuleBasedFieldMap.
        The object key.


        :param key: The key of this RuleBasedFieldMap.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this RuleBasedFieldMap.
        The object's model version.


        :return: The model_version of this RuleBasedFieldMap.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this RuleBasedFieldMap.
        The object's model version.


        :param model_version: The model_version of this RuleBasedFieldMap.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this RuleBasedFieldMap.

        :return: The parent_ref of this RuleBasedFieldMap.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this RuleBasedFieldMap.

        :param parent_ref: The parent_ref of this RuleBasedFieldMap.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def config_values(self):
        """
        Gets the config_values of this RuleBasedFieldMap.

        :return: The config_values of this RuleBasedFieldMap.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._config_values

    @config_values.setter
    def config_values(self, config_values):
        """
        Sets the config_values of this RuleBasedFieldMap.

        :param config_values: The config_values of this RuleBasedFieldMap.
        :type: oci.data_integration.models.ConfigValues
        """
        self._config_values = config_values

    @property
    def map_type(self):
        """
        Gets the map_type of this RuleBasedFieldMap.
        mapType

        Allowed values for this property are: "MAPBYNAME", "MAPBYPOSITION", "MAPBYPATTERN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The map_type of this RuleBasedFieldMap.
        :rtype: str
        """
        return self._map_type

    @map_type.setter
    def map_type(self, map_type):
        """
        Sets the map_type of this RuleBasedFieldMap.
        mapType


        :param map_type: The map_type of this RuleBasedFieldMap.
        :type: str
        """
        allowed_values = ["MAPBYNAME", "MAPBYPOSITION", "MAPBYPATTERN"]
        if not value_allowed_none_or_none_sentinel(map_type, allowed_values):
            map_type = 'UNKNOWN_ENUM_VALUE'
        self._map_type = map_type

    @property
    def from_pattern(self):
        """
        Gets the from_pattern of this RuleBasedFieldMap.
        The pattern to map from.


        :return: The from_pattern of this RuleBasedFieldMap.
        :rtype: str
        """
        return self._from_pattern

    @from_pattern.setter
    def from_pattern(self, from_pattern):
        """
        Sets the from_pattern of this RuleBasedFieldMap.
        The pattern to map from.


        :param from_pattern: The from_pattern of this RuleBasedFieldMap.
        :type: str
        """
        self._from_pattern = from_pattern

    @property
    def to_pattern(self):
        """
        Gets the to_pattern of this RuleBasedFieldMap.
        The pattern to map to.


        :return: The to_pattern of this RuleBasedFieldMap.
        :rtype: str
        """
        return self._to_pattern

    @to_pattern.setter
    def to_pattern(self, to_pattern):
        """
        Sets the to_pattern of this RuleBasedFieldMap.
        The pattern to map to.


        :param to_pattern: The to_pattern of this RuleBasedFieldMap.
        :type: str
        """
        self._to_pattern = to_pattern

    @property
    def is_java_regex_syntax(self):
        """
        Gets the is_java_regex_syntax of this RuleBasedFieldMap.
        Specifies whether the rule uses a java regex syntax.


        :return: The is_java_regex_syntax of this RuleBasedFieldMap.
        :rtype: bool
        """
        return self._is_java_regex_syntax

    @is_java_regex_syntax.setter
    def is_java_regex_syntax(self, is_java_regex_syntax):
        """
        Sets the is_java_regex_syntax of this RuleBasedFieldMap.
        Specifies whether the rule uses a java regex syntax.


        :param is_java_regex_syntax: The is_java_regex_syntax of this RuleBasedFieldMap.
        :type: bool
        """
        self._is_java_regex_syntax = is_java_regex_syntax

    @property
    def object_status(self):
        """
        Gets the object_status of this RuleBasedFieldMap.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this RuleBasedFieldMap.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this RuleBasedFieldMap.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this RuleBasedFieldMap.
        :type: int
        """
        self._object_status = object_status

    @property
    def from_rule_config(self):
        """
        Gets the from_rule_config of this RuleBasedFieldMap.

        :return: The from_rule_config of this RuleBasedFieldMap.
        :rtype: oci.data_integration.models.RuleTypeConfig
        """
        return self._from_rule_config

    @from_rule_config.setter
    def from_rule_config(self, from_rule_config):
        """
        Sets the from_rule_config of this RuleBasedFieldMap.

        :param from_rule_config: The from_rule_config of this RuleBasedFieldMap.
        :type: oci.data_integration.models.RuleTypeConfig
        """
        self._from_rule_config = from_rule_config

    @property
    def to_rule_config(self):
        """
        Gets the to_rule_config of this RuleBasedFieldMap.

        :return: The to_rule_config of this RuleBasedFieldMap.
        :rtype: oci.data_integration.models.RuleTypeConfig
        """
        return self._to_rule_config

    @to_rule_config.setter
    def to_rule_config(self, to_rule_config):
        """
        Sets the to_rule_config of this RuleBasedFieldMap.

        :param to_rule_config: The to_rule_config of this RuleBasedFieldMap.
        :type: oci.data_integration.models.RuleTypeConfig
        """
        self._to_rule_config = to_rule_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagedListSummary(object):
    """
    Summary of ManagedList
    """

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "CIDR_BLOCK"
    LIST_TYPE_CIDR_BLOCK = "CIDR_BLOCK"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "USERS"
    LIST_TYPE_USERS = "USERS"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "GROUPS"
    LIST_TYPE_GROUPS = "GROUPS"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "IPV4ADDRESS"
    LIST_TYPE_IPV4_ADDRESS = "IPV4ADDRESS"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "IPV6ADDRESS"
    LIST_TYPE_IPV6_ADDRESS = "IPV6ADDRESS"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "RESOURCE_OCID"
    LIST_TYPE_RESOURCE_OCID = "RESOURCE_OCID"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "REGION"
    LIST_TYPE_REGION = "REGION"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "COUNTRY"
    LIST_TYPE_COUNTRY = "COUNTRY"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "STATE"
    LIST_TYPE_STATE = "STATE"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "CITY"
    LIST_TYPE_CITY = "CITY"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "TAGS"
    LIST_TYPE_TAGS = "TAGS"

    #: A constant which can be used with the list_type property of a ManagedListSummary.
    #: This constant has a value of "GENERIC"
    LIST_TYPE_GENERIC = "GENERIC"

    #: A constant which can be used with the feed_provider property of a ManagedListSummary.
    #: This constant has a value of "CUSTOMER"
    FEED_PROVIDER_CUSTOMER = "CUSTOMER"

    #: A constant which can be used with the feed_provider property of a ManagedListSummary.
    #: This constant has a value of "ORACLE"
    FEED_PROVIDER_ORACLE = "ORACLE"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ManagedListSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagedListSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ManagedListSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this ManagedListSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this ManagedListSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ManagedListSummary.
        :type compartment_id: str

        :param source_managed_list_id:
            The value to assign to the source_managed_list_id property of this ManagedListSummary.
        :type source_managed_list_id: str

        :param list_type:
            The value to assign to the list_type property of this ManagedListSummary.
            Allowed values for this property are: "CIDR_BLOCK", "USERS", "GROUPS", "IPV4ADDRESS", "IPV6ADDRESS", "RESOURCE_OCID", "REGION", "COUNTRY", "STATE", "CITY", "TAGS", "GENERIC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type list_type: str

        :param feed_provider:
            The value to assign to the feed_provider property of this ManagedListSummary.
            Allowed values for this property are: "CUSTOMER", "ORACLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type feed_provider: str

        :param is_editable:
            The value to assign to the is_editable property of this ManagedListSummary.
        :type is_editable: bool

        :param list_items:
            The value to assign to the list_items property of this ManagedListSummary.
        :type list_items: list[str]

        :param time_created:
            The value to assign to the time_created property of this ManagedListSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ManagedListSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ManagedListSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecyle_details:
            The value to assign to the lifecyle_details property of this ManagedListSummary.
        :type lifecyle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ManagedListSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ManagedListSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this ManagedListSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'source_managed_list_id': 'str',
            'list_type': 'str',
            'feed_provider': 'str',
            'is_editable': 'bool',
            'list_items': 'list[str]',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecyle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'source_managed_list_id': 'sourceManagedListId',
            'list_type': 'listType',
            'feed_provider': 'feedProvider',
            'is_editable': 'isEditable',
            'list_items': 'listItems',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecyle_details': 'lifecyleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._source_managed_list_id = None
        self._list_type = None
        self._feed_provider = None
        self._is_editable = None
        self._list_items = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecyle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ManagedListSummary.
        Unique identifier that is immutable on creation


        :return: The id of this ManagedListSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagedListSummary.
        Unique identifier that is immutable on creation


        :param id: The id of this ManagedListSummary.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ManagedListSummary.
        ManagedList display name


        :return: The display_name of this ManagedListSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ManagedListSummary.
        ManagedList display name


        :param display_name: The display_name of this ManagedListSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this ManagedListSummary.
        ManagedList description


        :return: The description of this ManagedListSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ManagedListSummary.
        ManagedList description


        :param description: The description of this ManagedListSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ManagedListSummary.
        Compartment Identifier where the resource is created


        :return: The compartment_id of this ManagedListSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ManagedListSummary.
        Compartment Identifier where the resource is created


        :param compartment_id: The compartment_id of this ManagedListSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def source_managed_list_id(self):
        """
        Gets the source_managed_list_id of this ManagedListSummary.
        OCID of the Source ManagedList


        :return: The source_managed_list_id of this ManagedListSummary.
        :rtype: str
        """
        return self._source_managed_list_id

    @source_managed_list_id.setter
    def source_managed_list_id(self, source_managed_list_id):
        """
        Sets the source_managed_list_id of this ManagedListSummary.
        OCID of the Source ManagedList


        :param source_managed_list_id: The source_managed_list_id of this ManagedListSummary.
        :type: str
        """
        self._source_managed_list_id = source_managed_list_id

    @property
    def list_type(self):
        """
        **[Required]** Gets the list_type of this ManagedListSummary.
        type of the list

        Allowed values for this property are: "CIDR_BLOCK", "USERS", "GROUPS", "IPV4ADDRESS", "IPV6ADDRESS", "RESOURCE_OCID", "REGION", "COUNTRY", "STATE", "CITY", "TAGS", "GENERIC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The list_type of this ManagedListSummary.
        :rtype: str
        """
        return self._list_type

    @list_type.setter
    def list_type(self, list_type):
        """
        Sets the list_type of this ManagedListSummary.
        type of the list


        :param list_type: The list_type of this ManagedListSummary.
        :type: str
        """
        allowed_values = ["CIDR_BLOCK", "USERS", "GROUPS", "IPV4ADDRESS", "IPV6ADDRESS", "RESOURCE_OCID", "REGION", "COUNTRY", "STATE", "CITY", "TAGS", "GENERIC"]
        if not value_allowed_none_or_none_sentinel(list_type, allowed_values):
            list_type = 'UNKNOWN_ENUM_VALUE'
        self._list_type = list_type

    @property
    def feed_provider(self):
        """
        **[Required]** Gets the feed_provider of this ManagedListSummary.
        provider of the feed

        Allowed values for this property are: "CUSTOMER", "ORACLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The feed_provider of this ManagedListSummary.
        :rtype: str
        """
        return self._feed_provider

    @feed_provider.setter
    def feed_provider(self, feed_provider):
        """
        Sets the feed_provider of this ManagedListSummary.
        provider of the feed


        :param feed_provider: The feed_provider of this ManagedListSummary.
        :type: str
        """
        allowed_values = ["CUSTOMER", "ORACLE"]
        if not value_allowed_none_or_none_sentinel(feed_provider, allowed_values):
            feed_provider = 'UNKNOWN_ENUM_VALUE'
        self._feed_provider = feed_provider

    @property
    def is_editable(self):
        """
        Gets the is_editable of this ManagedListSummary.
        If this list is editable or not


        :return: The is_editable of this ManagedListSummary.
        :rtype: bool
        """
        return self._is_editable

    @is_editable.setter
    def is_editable(self, is_editable):
        """
        Sets the is_editable of this ManagedListSummary.
        If this list is editable or not


        :param is_editable: The is_editable of this ManagedListSummary.
        :type: bool
        """
        self._is_editable = is_editable

    @property
    def list_items(self):
        """
        **[Required]** Gets the list_items of this ManagedListSummary.
        List of ManagedListItem


        :return: The list_items of this ManagedListSummary.
        :rtype: list[str]
        """
        return self._list_items

    @list_items.setter
    def list_items(self, list_items):
        """
        Sets the list_items of this ManagedListSummary.
        List of ManagedListItem


        :param list_items: The list_items of this ManagedListSummary.
        :type: list[str]
        """
        self._list_items = list_items

    @property
    def time_created(self):
        """
        Gets the time_created of this ManagedListSummary.
        The date and time the managed list was created. Format defined by RFC3339.


        :return: The time_created of this ManagedListSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ManagedListSummary.
        The date and time the managed list was created. Format defined by RFC3339.


        :param time_created: The time_created of this ManagedListSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ManagedListSummary.
        The date and time the managed list was updated. Format defined by RFC3339.


        :return: The time_updated of this ManagedListSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ManagedListSummary.
        The date and time the managed list was updated. Format defined by RFC3339.


        :param time_updated: The time_updated of this ManagedListSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this ManagedListSummary.
        The current state of the resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ManagedListSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ManagedListSummary.
        The current state of the resource.


        :param lifecycle_state: The lifecycle_state of this ManagedListSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecyle_details(self):
        """
        Gets the lifecyle_details of this ManagedListSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecyle_details of this ManagedListSummary.
        :rtype: str
        """
        return self._lifecyle_details

    @lifecyle_details.setter
    def lifecyle_details(self, lifecyle_details):
        """
        Sets the lifecyle_details of this ManagedListSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecyle_details: The lifecyle_details of this ManagedListSummary.
        :type: str
        """
        self._lifecyle_details = lifecyle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ManagedListSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this ManagedListSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ManagedListSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this ManagedListSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ManagedListSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this ManagedListSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ManagedListSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this ManagedListSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this ManagedListSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        System tags can be viewed by users, but can only be created by the system.

        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this ManagedListSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this ManagedListSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        System tags can be viewed by users, but can only be created by the system.

        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this ManagedListSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TopologyRoutesToRelationshipDetails(object):
    """
    Defines route rule details for a `routesTo` relationship.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TopologyRoutesToRelationshipDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param destination_type:
            The value to assign to the destination_type property of this TopologyRoutesToRelationshipDetails.
        :type destination_type: str

        :param destination:
            The value to assign to the destination property of this TopologyRoutesToRelationshipDetails.
        :type destination: str

        :param route_table_id:
            The value to assign to the route_table_id property of this TopologyRoutesToRelationshipDetails.
        :type route_table_id: str

        """
        self.swagger_types = {
            'destination_type': 'str',
            'destination': 'str',
            'route_table_id': 'str'
        }

        self.attribute_map = {
            'destination_type': 'destinationType',
            'destination': 'destination',
            'route_table_id': 'routeTableId'
        }

        self._destination_type = None
        self._destination = None
        self._route_table_id = None

    @property
    def destination_type(self):
        """
        **[Required]** Gets the destination_type of this TopologyRoutesToRelationshipDetails.
        The destinationType can be set to one of two values:

        * Use `CIDR_BLOCK` if the rule's `destination` is an IP address range in CIDR notation.

        * Use `SERVICE_CIDR_BLOCK` if the rule's `destination` is the `cidrBlock` value for a :class:`Service`.


        :return: The destination_type of this TopologyRoutesToRelationshipDetails.
        :rtype: str
        """
        return self._destination_type

    @destination_type.setter
    def destination_type(self, destination_type):
        """
        Sets the destination_type of this TopologyRoutesToRelationshipDetails.
        The destinationType can be set to one of two values:

        * Use `CIDR_BLOCK` if the rule's `destination` is an IP address range in CIDR notation.

        * Use `SERVICE_CIDR_BLOCK` if the rule's `destination` is the `cidrBlock` value for a :class:`Service`.


        :param destination_type: The destination_type of this TopologyRoutesToRelationshipDetails.
        :type: str
        """
        self._destination_type = destination_type

    @property
    def destination(self):
        """
        **[Required]** Gets the destination of this TopologyRoutesToRelationshipDetails.
        An IP address range in CIDR notation or the `cidrBlock` value for a :class:`Service`.


        :return: The destination of this TopologyRoutesToRelationshipDetails.
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """
        Sets the destination of this TopologyRoutesToRelationshipDetails.
        An IP address range in CIDR notation or the `cidrBlock` value for a :class:`Service`.


        :param destination: The destination of this TopologyRoutesToRelationshipDetails.
        :type: str
        """
        self._destination = destination

    @property
    def route_table_id(self):
        """
        **[Required]** Gets the route_table_id of this TopologyRoutesToRelationshipDetails.
        The `OCID`__ of the routing table that contains the route rule.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The route_table_id of this TopologyRoutesToRelationshipDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this TopologyRoutesToRelationshipDetails.
        The `OCID`__ of the routing table that contains the route rule.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param route_table_id: The route_table_id of this TopologyRoutesToRelationshipDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AvailabilityHistorySummary(object):
    """
    Availability history of Management Agent.
    """

    #: A constant which can be used with the availability_status property of a AvailabilityHistorySummary.
    #: This constant has a value of "ACTIVE"
    AVAILABILITY_STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the availability_status property of a AvailabilityHistorySummary.
    #: This constant has a value of "SILENT"
    AVAILABILITY_STATUS_SILENT = "SILENT"

    #: A constant which can be used with the availability_status property of a AvailabilityHistorySummary.
    #: This constant has a value of "NOT_AVAILABLE"
    AVAILABILITY_STATUS_NOT_AVAILABLE = "NOT_AVAILABLE"

    def __init__(self, **kwargs):
        """
        Initializes a new AvailabilityHistorySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param management_agent_id:
            The value to assign to the management_agent_id property of this AvailabilityHistorySummary.
        :type management_agent_id: str

        :param availability_status:
            The value to assign to the availability_status property of this AvailabilityHistorySummary.
            Allowed values for this property are: "ACTIVE", "SILENT", "NOT_AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type availability_status: str

        :param time_availability_status_started:
            The value to assign to the time_availability_status_started property of this AvailabilityHistorySummary.
        :type time_availability_status_started: datetime

        :param time_availability_status_ended:
            The value to assign to the time_availability_status_ended property of this AvailabilityHistorySummary.
        :type time_availability_status_ended: datetime

        """
        self.swagger_types = {
            'management_agent_id': 'str',
            'availability_status': 'str',
            'time_availability_status_started': 'datetime',
            'time_availability_status_ended': 'datetime'
        }

        self.attribute_map = {
            'management_agent_id': 'managementAgentId',
            'availability_status': 'availabilityStatus',
            'time_availability_status_started': 'timeAvailabilityStatusStarted',
            'time_availability_status_ended': 'timeAvailabilityStatusEnded'
        }

        self._management_agent_id = None
        self._availability_status = None
        self._time_availability_status_started = None
        self._time_availability_status_ended = None

    @property
    def management_agent_id(self):
        """
        **[Required]** Gets the management_agent_id of this AvailabilityHistorySummary.
        agent identifier


        :return: The management_agent_id of this AvailabilityHistorySummary.
        :rtype: str
        """
        return self._management_agent_id

    @management_agent_id.setter
    def management_agent_id(self, management_agent_id):
        """
        Sets the management_agent_id of this AvailabilityHistorySummary.
        agent identifier


        :param management_agent_id: The management_agent_id of this AvailabilityHistorySummary.
        :type: str
        """
        self._management_agent_id = management_agent_id

    @property
    def availability_status(self):
        """
        **[Required]** Gets the availability_status of this AvailabilityHistorySummary.
        The availability status of managementAgent

        Allowed values for this property are: "ACTIVE", "SILENT", "NOT_AVAILABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The availability_status of this AvailabilityHistorySummary.
        :rtype: str
        """
        return self._availability_status

    @availability_status.setter
    def availability_status(self, availability_status):
        """
        Sets the availability_status of this AvailabilityHistorySummary.
        The availability status of managementAgent


        :param availability_status: The availability_status of this AvailabilityHistorySummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "SILENT", "NOT_AVAILABLE"]
        if not value_allowed_none_or_none_sentinel(availability_status, allowed_values):
            availability_status = 'UNKNOWN_ENUM_VALUE'
        self._availability_status = availability_status

    @property
    def time_availability_status_started(self):
        """
        Gets the time_availability_status_started of this AvailabilityHistorySummary.
        The time at which the Management Agent moved to the availability status. An RFC3339 formatted datetime string


        :return: The time_availability_status_started of this AvailabilityHistorySummary.
        :rtype: datetime
        """
        return self._time_availability_status_started

    @time_availability_status_started.setter
    def time_availability_status_started(self, time_availability_status_started):
        """
        Sets the time_availability_status_started of this AvailabilityHistorySummary.
        The time at which the Management Agent moved to the availability status. An RFC3339 formatted datetime string


        :param time_availability_status_started: The time_availability_status_started of this AvailabilityHistorySummary.
        :type: datetime
        """
        self._time_availability_status_started = time_availability_status_started

    @property
    def time_availability_status_ended(self):
        """
        Gets the time_availability_status_ended of this AvailabilityHistorySummary.
        The time till which the Management Agent was known to be in the availability status. An RFC3339 formatted datetime string


        :return: The time_availability_status_ended of this AvailabilityHistorySummary.
        :rtype: datetime
        """
        return self._time_availability_status_ended

    @time_availability_status_ended.setter
    def time_availability_status_ended(self, time_availability_status_ended):
        """
        Sets the time_availability_status_ended of this AvailabilityHistorySummary.
        The time till which the Management Agent was known to be in the availability status. An RFC3339 formatted datetime string


        :param time_availability_status_ended: The time_availability_status_ended of this AvailabilityHistorySummary.
        :type: datetime
        """
        self._time_availability_status_ended = time_availability_status_ended

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class IPSecConnection(object):
    """
    A connection between a DRG and CPE. This connection consists of multiple IPSec
    tunnels. Creating this connection is one of the steps required when setting up
    an IPSec VPN.

    **Important:**  Each tunnel in an IPSec connection can use either static routing or BGP dynamic
    routing (see the :class:`IPSecConnectionTunnel` object's
    `routing` attribute). Originally only static routing was supported and
    every IPSec connection was required to have at least one static route configured.
    To maintain backward compatibility in the API when support for BPG dynamic routing was introduced,
    the API accepts an empty list of static routes if you configure both of the IPSec tunnels to use
    BGP dynamic routing. If you switch a tunnel's routing from `BGP` to `STATIC`, you must first
    ensure that the IPSec connection is configured with at least one valid CIDR block static route.
    Oracle uses the IPSec connection's static routes when routing a tunnel's traffic *only*
    if that tunnel's `routing` attribute = `STATIC`. Otherwise the static routes are ignored.

    For more information about the workflow for setting up an IPSec connection, see
    `IPSec VPN`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPsec.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a IPSecConnection.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a IPSecConnection.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a IPSecConnection.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a IPSecConnection.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the cpe_local_identifier_type property of a IPSecConnection.
    #: This constant has a value of "IP_ADDRESS"
    CPE_LOCAL_IDENTIFIER_TYPE_IP_ADDRESS = "IP_ADDRESS"

    #: A constant which can be used with the cpe_local_identifier_type property of a IPSecConnection.
    #: This constant has a value of "HOSTNAME"
    CPE_LOCAL_IDENTIFIER_TYPE_HOSTNAME = "HOSTNAME"

    def __init__(self, **kwargs):
        """
        Initializes a new IPSecConnection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this IPSecConnection.
        :type compartment_id: str

        :param cpe_id:
            The value to assign to the cpe_id property of this IPSecConnection.
        :type cpe_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this IPSecConnection.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this IPSecConnection.
        :type display_name: str

        :param drg_id:
            The value to assign to the drg_id property of this IPSecConnection.
        :type drg_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this IPSecConnection.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this IPSecConnection.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this IPSecConnection.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param cpe_local_identifier:
            The value to assign to the cpe_local_identifier property of this IPSecConnection.
        :type cpe_local_identifier: str

        :param cpe_local_identifier_type:
            The value to assign to the cpe_local_identifier_type property of this IPSecConnection.
            Allowed values for this property are: "IP_ADDRESS", "HOSTNAME", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type cpe_local_identifier_type: str

        :param static_routes:
            The value to assign to the static_routes property of this IPSecConnection.
        :type static_routes: list[str]

        :param time_created:
            The value to assign to the time_created property of this IPSecConnection.
        :type time_created: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'cpe_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'drg_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'cpe_local_identifier': 'str',
            'cpe_local_identifier_type': 'str',
            'static_routes': 'list[str]',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'cpe_id': 'cpeId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'drg_id': 'drgId',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'cpe_local_identifier': 'cpeLocalIdentifier',
            'cpe_local_identifier_type': 'cpeLocalIdentifierType',
            'static_routes': 'staticRoutes',
            'time_created': 'timeCreated'
        }

        self._compartment_id = None
        self._cpe_id = None
        self._defined_tags = None
        self._display_name = None
        self._drg_id = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._cpe_local_identifier = None
        self._cpe_local_identifier_type = None
        self._static_routes = None
        self._time_created = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this IPSecConnection.
        The OCID of the compartment containing the IPSec connection.


        :return: The compartment_id of this IPSecConnection.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this IPSecConnection.
        The OCID of the compartment containing the IPSec connection.


        :param compartment_id: The compartment_id of this IPSecConnection.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def cpe_id(self):
        """
        **[Required]** Gets the cpe_id of this IPSecConnection.
        The OCID of the :class:`Cpe` object.


        :return: The cpe_id of this IPSecConnection.
        :rtype: str
        """
        return self._cpe_id

    @cpe_id.setter
    def cpe_id(self, cpe_id):
        """
        Sets the cpe_id of this IPSecConnection.
        The OCID of the :class:`Cpe` object.


        :param cpe_id: The cpe_id of this IPSecConnection.
        :type: str
        """
        self._cpe_id = cpe_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this IPSecConnection.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this IPSecConnection.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this IPSecConnection.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this IPSecConnection.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this IPSecConnection.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this IPSecConnection.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this IPSecConnection.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this IPSecConnection.
        :type: str
        """
        self._display_name = display_name

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this IPSecConnection.
        The `OCID`__ of the DRG.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The drg_id of this IPSecConnection.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this IPSecConnection.
        The `OCID`__ of the DRG.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param drg_id: The drg_id of this IPSecConnection.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this IPSecConnection.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this IPSecConnection.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this IPSecConnection.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this IPSecConnection.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this IPSecConnection.
        The IPSec connection's Oracle ID (`OCID`__).

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this IPSecConnection.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IPSecConnection.
        The IPSec connection's Oracle ID (`OCID`__).

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this IPSecConnection.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this IPSecConnection.
        The IPSec connection's current state.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this IPSecConnection.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this IPSecConnection.
        The IPSec connection's current state.


        :param lifecycle_state: The lifecycle_state of this IPSecConnection.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def cpe_local_identifier(self):
        """
        Gets the cpe_local_identifier of this IPSecConnection.
        Your identifier for your CPE device. Can be either an IP address or a hostname (specifically,
        the fully qualified domain name (FQDN)). The type of identifier here must correspond
        to the value for `cpeLocalIdentifierType`.

        If you don't provide a value when creating the IPSec connection, the `ipAddress` attribute
        for the :class:`Cpe` object specified by `cpeId` is used as the `cpeLocalIdentifier`.

        For information about why you'd provide this value, see
        `If Your CPE Is Behind a NAT Device`__.

        Example IP address: `10.0.3.3`

        Example hostname: `cpe.example.com`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm#nat


        :return: The cpe_local_identifier of this IPSecConnection.
        :rtype: str
        """
        return self._cpe_local_identifier

    @cpe_local_identifier.setter
    def cpe_local_identifier(self, cpe_local_identifier):
        """
        Sets the cpe_local_identifier of this IPSecConnection.
        Your identifier for your CPE device. Can be either an IP address or a hostname (specifically,
        the fully qualified domain name (FQDN)). The type of identifier here must correspond
        to the value for `cpeLocalIdentifierType`.

        If you don't provide a value when creating the IPSec connection, the `ipAddress` attribute
        for the :class:`Cpe` object specified by `cpeId` is used as the `cpeLocalIdentifier`.

        For information about why you'd provide this value, see
        `If Your CPE Is Behind a NAT Device`__.

        Example IP address: `10.0.3.3`

        Example hostname: `cpe.example.com`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm#nat


        :param cpe_local_identifier: The cpe_local_identifier of this IPSecConnection.
        :type: str
        """
        self._cpe_local_identifier = cpe_local_identifier

    @property
    def cpe_local_identifier_type(self):
        """
        Gets the cpe_local_identifier_type of this IPSecConnection.
        The type of identifier for your CPE device. The value here must correspond to the value
        for `cpeLocalIdentifier`.

        Allowed values for this property are: "IP_ADDRESS", "HOSTNAME", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The cpe_local_identifier_type of this IPSecConnection.
        :rtype: str
        """
        return self._cpe_local_identifier_type

    @cpe_local_identifier_type.setter
    def cpe_local_identifier_type(self, cpe_local_identifier_type):
        """
        Sets the cpe_local_identifier_type of this IPSecConnection.
        The type of identifier for your CPE device. The value here must correspond to the value
        for `cpeLocalIdentifier`.


        :param cpe_local_identifier_type: The cpe_local_identifier_type of this IPSecConnection.
        :type: str
        """
        allowed_values = ["IP_ADDRESS", "HOSTNAME"]
        if not value_allowed_none_or_none_sentinel(cpe_local_identifier_type, allowed_values):
            cpe_local_identifier_type = 'UNKNOWN_ENUM_VALUE'
        self._cpe_local_identifier_type = cpe_local_identifier_type

    @property
    def static_routes(self):
        """
        **[Required]** Gets the static_routes of this IPSecConnection.
        Static routes to the CPE. The CIDR must not be a
        multicast address or class E address.

        Used for routing a given IPSec tunnel's traffic only if the tunnel
        is using static routing. If you configure at least one tunnel to use static routing, then
        you must provide at least one valid static route. If you configure both
        tunnels to use BGP dynamic routing, you can provide an empty list for the static routes.

        The CIDR can be either IPv4 or IPv6. IPv6 addressing is supported for all commercial and government regions.
        See `IPv6 Addresses`__.

        Example: `10.0.1.0/24`

        Example: `2001:db8::/32`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The static_routes of this IPSecConnection.
        :rtype: list[str]
        """
        return self._static_routes

    @static_routes.setter
    def static_routes(self, static_routes):
        """
        Sets the static_routes of this IPSecConnection.
        Static routes to the CPE. The CIDR must not be a
        multicast address or class E address.

        Used for routing a given IPSec tunnel's traffic only if the tunnel
        is using static routing. If you configure at least one tunnel to use static routing, then
        you must provide at least one valid static route. If you configure both
        tunnels to use BGP dynamic routing, you can provide an empty list for the static routes.

        The CIDR can be either IPv4 or IPv6. IPv6 addressing is supported for all commercial and government regions.
        See `IPv6 Addresses`__.

        Example: `10.0.1.0/24`

        Example: `2001:db8::/32`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param static_routes: The static_routes of this IPSecConnection.
        :type: list[str]
        """
        self._static_routes = static_routes

    @property
    def time_created(self):
        """
        Gets the time_created of this IPSecConnection.
        The date and time the IPSec connection was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this IPSecConnection.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this IPSecConnection.
        The date and time the IPSec connection was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this IPSecConnection.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .job_infrastructure_configuration_details import JobInfrastructureConfigurationDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StandaloneJobInfrastructureConfigurationDetails(JobInfrastructureConfigurationDetails):
    """
    The standalone job infrastructure configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StandaloneJobInfrastructureConfigurationDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_science.models.StandaloneJobInfrastructureConfigurationDetails.job_infrastructure_type` attribute
        of this class is ``STANDALONE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param job_infrastructure_type:
            The value to assign to the job_infrastructure_type property of this StandaloneJobInfrastructureConfigurationDetails.
            Allowed values for this property are: "STANDALONE"
        :type job_infrastructure_type: str

        :param shape_name:
            The value to assign to the shape_name property of this StandaloneJobInfrastructureConfigurationDetails.
        :type shape_name: str

        :param subnet_id:
            The value to assign to the subnet_id property of this StandaloneJobInfrastructureConfigurationDetails.
        :type subnet_id: str

        :param block_storage_size_in_gbs:
            The value to assign to the block_storage_size_in_gbs property of this StandaloneJobInfrastructureConfigurationDetails.
        :type block_storage_size_in_gbs: int

        """
        self.swagger_types = {
            'job_infrastructure_type': 'str',
            'shape_name': 'str',
            'subnet_id': 'str',
            'block_storage_size_in_gbs': 'int'
        }

        self.attribute_map = {
            'job_infrastructure_type': 'jobInfrastructureType',
            'shape_name': 'shapeName',
            'subnet_id': 'subnetId',
            'block_storage_size_in_gbs': 'blockStorageSizeInGBs'
        }

        self._job_infrastructure_type = None
        self._shape_name = None
        self._subnet_id = None
        self._block_storage_size_in_gbs = None
        self._job_infrastructure_type = 'STANDALONE'

    @property
    def shape_name(self):
        """
        **[Required]** Gets the shape_name of this StandaloneJobInfrastructureConfigurationDetails.
        The shape used to launch the job run instances.


        :return: The shape_name of this StandaloneJobInfrastructureConfigurationDetails.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this StandaloneJobInfrastructureConfigurationDetails.
        The shape used to launch the job run instances.


        :param shape_name: The shape_name of this StandaloneJobInfrastructureConfigurationDetails.
        :type: str
        """
        self._shape_name = shape_name

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this StandaloneJobInfrastructureConfigurationDetails.
        The subnet to create a secondary vnic in to attach to the instance running the job


        :return: The subnet_id of this StandaloneJobInfrastructureConfigurationDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this StandaloneJobInfrastructureConfigurationDetails.
        The subnet to create a secondary vnic in to attach to the instance running the job


        :param subnet_id: The subnet_id of this StandaloneJobInfrastructureConfigurationDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def block_storage_size_in_gbs(self):
        """
        **[Required]** Gets the block_storage_size_in_gbs of this StandaloneJobInfrastructureConfigurationDetails.
        The size of the block storage volume to attach to the instance running the job


        :return: The block_storage_size_in_gbs of this StandaloneJobInfrastructureConfigurationDetails.
        :rtype: int
        """
        return self._block_storage_size_in_gbs

    @block_storage_size_in_gbs.setter
    def block_storage_size_in_gbs(self, block_storage_size_in_gbs):
        """
        Sets the block_storage_size_in_gbs of this StandaloneJobInfrastructureConfigurationDetails.
        The size of the block storage volume to attach to the instance running the job


        :param block_storage_size_in_gbs: The block_storage_size_in_gbs of this StandaloneJobInfrastructureConfigurationDetails.
        :type: int
        """
        self._block_storage_size_in_gbs = block_storage_size_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NamespaceSummary(object):
    """
    The is the namespace summary of a tenancy in Logan Analytics application
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NamespaceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param namespace_name:
            The value to assign to the namespace_name property of this NamespaceSummary.
        :type namespace_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this NamespaceSummary.
        :type compartment_id: str

        :param is_onboarded:
            The value to assign to the is_onboarded property of this NamespaceSummary.
        :type is_onboarded: bool

        :param is_log_set_enabled:
            The value to assign to the is_log_set_enabled property of this NamespaceSummary.
        :type is_log_set_enabled: bool

        :param is_data_ever_ingested:
            The value to assign to the is_data_ever_ingested property of this NamespaceSummary.
        :type is_data_ever_ingested: bool

        """
        self.swagger_types = {
            'namespace_name': 'str',
            'compartment_id': 'str',
            'is_onboarded': 'bool',
            'is_log_set_enabled': 'bool',
            'is_data_ever_ingested': 'bool'
        }

        self.attribute_map = {
            'namespace_name': 'namespaceName',
            'compartment_id': 'compartmentId',
            'is_onboarded': 'isOnboarded',
            'is_log_set_enabled': 'isLogSetEnabled',
            'is_data_ever_ingested': 'isDataEverIngested'
        }

        self._namespace_name = None
        self._compartment_id = None
        self._is_onboarded = None
        self._is_log_set_enabled = None
        self._is_data_ever_ingested = None

    @property
    def namespace_name(self):
        """
        **[Required]** Gets the namespace_name of this NamespaceSummary.
        This is the namespace name of a tenancy


        :return: The namespace_name of this NamespaceSummary.
        :rtype: str
        """
        return self._namespace_name

    @namespace_name.setter
    def namespace_name(self, namespace_name):
        """
        Sets the namespace_name of this NamespaceSummary.
        This is the namespace name of a tenancy


        :param namespace_name: The namespace_name of this NamespaceSummary.
        :type: str
        """
        self._namespace_name = namespace_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this NamespaceSummary.
        The is the tenancy ID


        :return: The compartment_id of this NamespaceSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this NamespaceSummary.
        The is the tenancy ID


        :param compartment_id: The compartment_id of this NamespaceSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_onboarded(self):
        """
        **[Required]** Gets the is_onboarded of this NamespaceSummary.
        This indicates if the tenancy is onboarded to Logging Analytics


        :return: The is_onboarded of this NamespaceSummary.
        :rtype: bool
        """
        return self._is_onboarded

    @is_onboarded.setter
    def is_onboarded(self, is_onboarded):
        """
        Sets the is_onboarded of this NamespaceSummary.
        This indicates if the tenancy is onboarded to Logging Analytics


        :param is_onboarded: The is_onboarded of this NamespaceSummary.
        :type: bool
        """
        self._is_onboarded = is_onboarded

    @property
    def is_log_set_enabled(self):
        """
        Gets the is_log_set_enabled of this NamespaceSummary.
        This indicates if the log set feature is enabled for the tenancy


        :return: The is_log_set_enabled of this NamespaceSummary.
        :rtype: bool
        """
        return self._is_log_set_enabled

    @is_log_set_enabled.setter
    def is_log_set_enabled(self, is_log_set_enabled):
        """
        Sets the is_log_set_enabled of this NamespaceSummary.
        This indicates if the log set feature is enabled for the tenancy


        :param is_log_set_enabled: The is_log_set_enabled of this NamespaceSummary.
        :type: bool
        """
        self._is_log_set_enabled = is_log_set_enabled

    @property
    def is_data_ever_ingested(self):
        """
        Gets the is_data_ever_ingested of this NamespaceSummary.
        This indicates if data has ever been ingested for the tenancy in Logging Analytics


        :return: The is_data_ever_ingested of this NamespaceSummary.
        :rtype: bool
        """
        return self._is_data_ever_ingested

    @is_data_ever_ingested.setter
    def is_data_ever_ingested(self, is_data_ever_ingested):
        """
        Sets the is_data_ever_ingested of this NamespaceSummary.
        This indicates if data has ever been ingested for the tenancy in Logging Analytics


        :param is_data_ever_ingested: The is_data_ever_ingested of this NamespaceSummary.
        :type: bool
        """
        self._is_data_ever_ingested = is_data_ever_ingested

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateManagementAgentInstallKeyDetails(object):
    """
    The information about new Management Agent install Key.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateManagementAgentInstallKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateManagementAgentInstallKeyDetails.
        :type display_name: str

        :param allowed_key_install_count:
            The value to assign to the allowed_key_install_count property of this CreateManagementAgentInstallKeyDetails.
        :type allowed_key_install_count: int

        :param time_expires:
            The value to assign to the time_expires property of this CreateManagementAgentInstallKeyDetails.
        :type time_expires: datetime

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateManagementAgentInstallKeyDetails.
        :type compartment_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'allowed_key_install_count': 'int',
            'time_expires': 'datetime',
            'compartment_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'allowed_key_install_count': 'allowedKeyInstallCount',
            'time_expires': 'timeExpires',
            'compartment_id': 'compartmentId'
        }

        self._display_name = None
        self._allowed_key_install_count = None
        self._time_expires = None
        self._compartment_id = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateManagementAgentInstallKeyDetails.
        Management Agent install Key Name


        :return: The display_name of this CreateManagementAgentInstallKeyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateManagementAgentInstallKeyDetails.
        Management Agent install Key Name


        :param display_name: The display_name of this CreateManagementAgentInstallKeyDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def allowed_key_install_count(self):
        """
        Gets the allowed_key_install_count of this CreateManagementAgentInstallKeyDetails.
        Total number of install for this keys


        :return: The allowed_key_install_count of this CreateManagementAgentInstallKeyDetails.
        :rtype: int
        """
        return self._allowed_key_install_count

    @allowed_key_install_count.setter
    def allowed_key_install_count(self, allowed_key_install_count):
        """
        Sets the allowed_key_install_count of this CreateManagementAgentInstallKeyDetails.
        Total number of install for this keys


        :param allowed_key_install_count: The allowed_key_install_count of this CreateManagementAgentInstallKeyDetails.
        :type: int
        """
        self._allowed_key_install_count = allowed_key_install_count

    @property
    def time_expires(self):
        """
        Gets the time_expires of this CreateManagementAgentInstallKeyDetails.
        date after which key would expire after creation


        :return: The time_expires of this CreateManagementAgentInstallKeyDetails.
        :rtype: datetime
        """
        return self._time_expires

    @time_expires.setter
    def time_expires(self, time_expires):
        """
        Sets the time_expires of this CreateManagementAgentInstallKeyDetails.
        date after which key would expire after creation


        :param time_expires: The time_expires of this CreateManagementAgentInstallKeyDetails.
        :type: datetime
        """
        self._time_expires = time_expires

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateManagementAgentInstallKeyDetails.
        Compartment Identifier


        :return: The compartment_id of this CreateManagementAgentInstallKeyDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateManagementAgentInstallKeyDetails.
        Compartment Identifier


        :param compartment_id: The compartment_id of this CreateManagementAgentInstallKeyDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .preemption_action import PreemptionAction
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TerminatePreemptionAction(PreemptionAction):
    """
    Terminates the preemptible instance when it is interrupted for eviction.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TerminatePreemptionAction object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.TerminatePreemptionAction.type` attribute
        of this class is ``TERMINATE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this TerminatePreemptionAction.
            Allowed values for this property are: "TERMINATE"
        :type type: str

        :param preserve_boot_volume:
            The value to assign to the preserve_boot_volume property of this TerminatePreemptionAction.
        :type preserve_boot_volume: bool

        """
        self.swagger_types = {
            'type': 'str',
            'preserve_boot_volume': 'bool'
        }

        self.attribute_map = {
            'type': 'type',
            'preserve_boot_volume': 'preserveBootVolume'
        }

        self._type = None
        self._preserve_boot_volume = None
        self._type = 'TERMINATE'

    @property
    def preserve_boot_volume(self):
        """
        Gets the preserve_boot_volume of this TerminatePreemptionAction.
        Whether to preserve the boot volume that was used to launch the preemptible instance when the instance is terminated. Defaults to false if not specified.


        :return: The preserve_boot_volume of this TerminatePreemptionAction.
        :rtype: bool
        """
        return self._preserve_boot_volume

    @preserve_boot_volume.setter
    def preserve_boot_volume(self, preserve_boot_volume):
        """
        Sets the preserve_boot_volume of this TerminatePreemptionAction.
        Whether to preserve the boot volume that was used to launch the preemptible instance when the instance is terminated. Defaults to false if not specified.


        :param preserve_boot_volume: The preserve_boot_volume of this TerminatePreemptionAction.
        :type: bool
        """
        self._preserve_boot_volume = preserve_boot_volume

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataAssetExportScope(object):
    """
    Scope of asset export, which consists of a container object (bucket, folder, schema, etc) within the asset,
    and types of child objects contained by that object to be included.
    objectKey - Key of the container object to be exported. For example, key of schema_1.
    exportTypeIds - Type key(s) of objects within the container object to be exported. For example, type key of table or view.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataAssetExportScope object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_key:
            The value to assign to the object_key property of this DataAssetExportScope.
        :type object_key: str

        :param export_type_ids:
            The value to assign to the export_type_ids property of this DataAssetExportScope.
        :type export_type_ids: list[str]

        """
        self.swagger_types = {
            'object_key': 'str',
            'export_type_ids': 'list[str]'
        }

        self.attribute_map = {
            'object_key': 'objectKey',
            'export_type_ids': 'exportTypeIds'
        }

        self._object_key = None
        self._export_type_ids = None

    @property
    def object_key(self):
        """
        Gets the object_key of this DataAssetExportScope.
        Unique key of the object selected for export.


        :return: The object_key of this DataAssetExportScope.
        :rtype: str
        """
        return self._object_key

    @object_key.setter
    def object_key(self, object_key):
        """
        Sets the object_key of this DataAssetExportScope.
        Unique key of the object selected for export.


        :param object_key: The object_key of this DataAssetExportScope.
        :type: str
        """
        self._object_key = object_key

    @property
    def export_type_ids(self):
        """
        Gets the export_type_ids of this DataAssetExportScope.
        Array of type keys selected for export.


        :return: The export_type_ids of this DataAssetExportScope.
        :rtype: list[str]
        """
        return self._export_type_ids

    @export_type_ids.setter
    def export_type_ids(self, export_type_ids):
        """
        Sets the export_type_ids of this DataAssetExportScope.
        Array of type keys selected for export.


        :param export_type_ids: The export_type_ids of this DataAssetExportScope.
        :type: list[str]
        """
        self._export_type_ids = export_type_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SpanLog(object):
    """
    Definition of a log which is a key value pair of log data.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SpanLog object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param log_key:
            The value to assign to the log_key property of this SpanLog.
        :type log_key: str

        :param log_value:
            The value to assign to the log_value property of this SpanLog.
        :type log_value: str

        """
        self.swagger_types = {
            'log_key': 'str',
            'log_value': 'str'
        }

        self.attribute_map = {
            'log_key': 'logKey',
            'log_value': 'logValue'
        }

        self._log_key = None
        self._log_value = None

    @property
    def log_key(self):
        """
        **[Required]** Gets the log_key of this SpanLog.
        Key that specifies the log name.


        :return: The log_key of this SpanLog.
        :rtype: str
        """
        return self._log_key

    @log_key.setter
    def log_key(self, log_key):
        """
        Sets the log_key of this SpanLog.
        Key that specifies the log name.


        :param log_key: The log_key of this SpanLog.
        :type: str
        """
        self._log_key = log_key

    @property
    def log_value(self):
        """
        **[Required]** Gets the log_value of this SpanLog.
        Value associated with the log key.


        :return: The log_value of this SpanLog.
        :rtype: str
        """
        return self._log_value

    @log_value.setter
    def log_value(self, log_value):
        """
        Sets the log_value of this SpanLog.
        Value associated with the log key.


        :param log_value: The log_value of this SpanLog.
        :type: str
        """
        self._log_value = log_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CategoryLogDetails(object):
    """
    The log details for each category.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CategoryLogDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param access:
            The value to assign to the access property of this CategoryLogDetails.
        :type access: oci.data_science.models.LogDetails

        :param predict:
            The value to assign to the predict property of this CategoryLogDetails.
        :type predict: oci.data_science.models.LogDetails

        """
        self.swagger_types = {
            'access': 'LogDetails',
            'predict': 'LogDetails'
        }

        self.attribute_map = {
            'access': 'access',
            'predict': 'predict'
        }

        self._access = None
        self._predict = None

    @property
    def access(self):
        """
        Gets the access of this CategoryLogDetails.

        :return: The access of this CategoryLogDetails.
        :rtype: oci.data_science.models.LogDetails
        """
        return self._access

    @access.setter
    def access(self, access):
        """
        Sets the access of this CategoryLogDetails.

        :param access: The access of this CategoryLogDetails.
        :type: oci.data_science.models.LogDetails
        """
        self._access = access

    @property
    def predict(self):
        """
        Gets the predict of this CategoryLogDetails.

        :return: The predict of this CategoryLogDetails.
        :rtype: oci.data_science.models.LogDetails
        """
        return self._predict

    @predict.setter
    def predict(self, predict):
        """
        Sets the predict of this CategoryLogDetails.

        :param predict: The predict of this CategoryLogDetails.
        :type: oci.data_science.models.LogDetails
        """
        self._predict = predict

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateBootVolumeKmsKeyDetails(object):
    """
    UpdateBootVolumeKmsKeyDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateBootVolumeKmsKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kms_key_id:
            The value to assign to the kms_key_id property of this UpdateBootVolumeKmsKeyDetails.
        :type kms_key_id: str

        """
        self.swagger_types = {
            'kms_key_id': 'str'
        }

        self.attribute_map = {
            'kms_key_id': 'kmsKeyId'
        }

        self._kms_key_id = None

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        The OCID of the new Key Management key to assign to protect the specified volume.
        This key has to be a valid Key Management key, and policies must exist to allow the user and the Block Volume service to access this key.
        If you specify the same OCID as the previous key's OCID, the Block Volume service will use it to regenerate a volume encryption key.


        :return: The kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        The OCID of the new Key Management key to assign to protect the specified volume.
        This key has to be a valid Key Management key, and policies must exist to allow the user and the Block Volume service to access this key.
        If you specify the same OCID as the previous key's OCID, the Block Volume service will use it to regenerate a volume encryption key.


        :param kms_key_id: The kms_key_id of this UpdateBootVolumeKmsKeyDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .secret_rule import SecretRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecretReuseRule(SecretRule):
    """
    A rule that disallows reuse of previously used secret content by the specified secret.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SecretReuseRule object with values from keyword arguments. The default value of the :py:attr:`~oci.vault.models.SecretReuseRule.rule_type` attribute
        of this class is ``SECRET_REUSE_RULE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rule_type:
            The value to assign to the rule_type property of this SecretReuseRule.
            Allowed values for this property are: "SECRET_EXPIRY_RULE", "SECRET_REUSE_RULE"
        :type rule_type: str

        :param is_enforced_on_deleted_secret_versions:
            The value to assign to the is_enforced_on_deleted_secret_versions property of this SecretReuseRule.
        :type is_enforced_on_deleted_secret_versions: bool

        """
        self.swagger_types = {
            'rule_type': 'str',
            'is_enforced_on_deleted_secret_versions': 'bool'
        }

        self.attribute_map = {
            'rule_type': 'ruleType',
            'is_enforced_on_deleted_secret_versions': 'isEnforcedOnDeletedSecretVersions'
        }

        self._rule_type = None
        self._is_enforced_on_deleted_secret_versions = None
        self._rule_type = 'SECRET_REUSE_RULE'

    @property
    def is_enforced_on_deleted_secret_versions(self):
        """
        Gets the is_enforced_on_deleted_secret_versions of this SecretReuseRule.
        A property indicating whether the rule is applied even if the secret version with the content you are trying to reuse was deleted.


        :return: The is_enforced_on_deleted_secret_versions of this SecretReuseRule.
        :rtype: bool
        """
        return self._is_enforced_on_deleted_secret_versions

    @is_enforced_on_deleted_secret_versions.setter
    def is_enforced_on_deleted_secret_versions(self, is_enforced_on_deleted_secret_versions):
        """
        Sets the is_enforced_on_deleted_secret_versions of this SecretReuseRule.
        A property indicating whether the rule is applied even if the secret version with the content you are trying to reuse was deleted.


        :param is_enforced_on_deleted_secret_versions: The is_enforced_on_deleted_secret_versions of this SecretReuseRule.
        :type: bool
        """
        self._is_enforced_on_deleted_secret_versions = is_enforced_on_deleted_secret_versions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImportDataAssetJobResult(object):
    """
    Information about a data asset import operation.
    """

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "CREATED"
    IMPORT_JOB_EXECUTION_STATUS_CREATED = "CREATED"

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "IN_PROGRESS"
    IMPORT_JOB_EXECUTION_STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "INACTIVE"
    IMPORT_JOB_EXECUTION_STATUS_INACTIVE = "INACTIVE"

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "FAILED"
    IMPORT_JOB_EXECUTION_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "SUCCEEDED"
    IMPORT_JOB_EXECUTION_STATUS_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "CANCELED"
    IMPORT_JOB_EXECUTION_STATUS_CANCELED = "CANCELED"

    #: A constant which can be used with the import_job_execution_status property of a ImportDataAssetJobResult.
    #: This constant has a value of "SUCCEEDED_WITH_WARNINGS"
    IMPORT_JOB_EXECUTION_STATUS_SUCCEEDED_WITH_WARNINGS = "SUCCEEDED_WITH_WARNINGS"

    def __init__(self, **kwargs):
        """
        Initializes a new ImportDataAssetJobResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_asset_key:
            The value to assign to the data_asset_key property of this ImportDataAssetJobResult.
        :type data_asset_key: str

        :param import_job_definition_key:
            The value to assign to the import_job_definition_key property of this ImportDataAssetJobResult.
        :type import_job_definition_key: str

        :param import_job_key:
            The value to assign to the import_job_key property of this ImportDataAssetJobResult.
        :type import_job_key: str

        :param import_job_execution_key:
            The value to assign to the import_job_execution_key property of this ImportDataAssetJobResult.
        :type import_job_execution_key: str

        :param import_job_execution_status:
            The value to assign to the import_job_execution_status property of this ImportDataAssetJobResult.
            Allowed values for this property are: "CREATED", "IN_PROGRESS", "INACTIVE", "FAILED", "SUCCEEDED", "CANCELED", "SUCCEEDED_WITH_WARNINGS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type import_job_execution_status: str

        """
        self.swagger_types = {
            'data_asset_key': 'str',
            'import_job_definition_key': 'str',
            'import_job_key': 'str',
            'import_job_execution_key': 'str',
            'import_job_execution_status': 'str'
        }

        self.attribute_map = {
            'data_asset_key': 'dataAssetKey',
            'import_job_definition_key': 'importJobDefinitionKey',
            'import_job_key': 'importJobKey',
            'import_job_execution_key': 'importJobExecutionKey',
            'import_job_execution_status': 'importJobExecutionStatus'
        }

        self._data_asset_key = None
        self._import_job_definition_key = None
        self._import_job_key = None
        self._import_job_execution_key = None
        self._import_job_execution_status = None

    @property
    def data_asset_key(self):
        """
        **[Required]** Gets the data_asset_key of this ImportDataAssetJobResult.
        The unique key of the data asset on which import is triggered.


        :return: The data_asset_key of this ImportDataAssetJobResult.
        :rtype: str
        """
        return self._data_asset_key

    @data_asset_key.setter
    def data_asset_key(self, data_asset_key):
        """
        Sets the data_asset_key of this ImportDataAssetJobResult.
        The unique key of the data asset on which import is triggered.


        :param data_asset_key: The data_asset_key of this ImportDataAssetJobResult.
        :type: str
        """
        self._data_asset_key = data_asset_key

    @property
    def import_job_definition_key(self):
        """
        Gets the import_job_definition_key of this ImportDataAssetJobResult.
        The unique key of the job definition resource that is used for the import.


        :return: The import_job_definition_key of this ImportDataAssetJobResult.
        :rtype: str
        """
        return self._import_job_definition_key

    @import_job_definition_key.setter
    def import_job_definition_key(self, import_job_definition_key):
        """
        Sets the import_job_definition_key of this ImportDataAssetJobResult.
        The unique key of the job definition resource that is used for the import.


        :param import_job_definition_key: The import_job_definition_key of this ImportDataAssetJobResult.
        :type: str
        """
        self._import_job_definition_key = import_job_definition_key

    @property
    def import_job_key(self):
        """
        Gets the import_job_key of this ImportDataAssetJobResult.
        The unique key of the job policy for the import.


        :return: The import_job_key of this ImportDataAssetJobResult.
        :rtype: str
        """
        return self._import_job_key

    @import_job_key.setter
    def import_job_key(self, import_job_key):
        """
        Sets the import_job_key of this ImportDataAssetJobResult.
        The unique key of the job policy for the import.


        :param import_job_key: The import_job_key of this ImportDataAssetJobResult.
        :type: str
        """
        self._import_job_key = import_job_key

    @property
    def import_job_execution_key(self):
        """
        Gets the import_job_execution_key of this ImportDataAssetJobResult.
        The unique key of the parent job execution for which the log resource is created.


        :return: The import_job_execution_key of this ImportDataAssetJobResult.
        :rtype: str
        """
        return self._import_job_execution_key

    @import_job_execution_key.setter
    def import_job_execution_key(self, import_job_execution_key):
        """
        Sets the import_job_execution_key of this ImportDataAssetJobResult.
        The unique key of the parent job execution for which the log resource is created.


        :param import_job_execution_key: The import_job_execution_key of this ImportDataAssetJobResult.
        :type: str
        """
        self._import_job_execution_key = import_job_execution_key

    @property
    def import_job_execution_status(self):
        """
        Gets the import_job_execution_status of this ImportDataAssetJobResult.
        The status of the import job execution.

        Allowed values for this property are: "CREATED", "IN_PROGRESS", "INACTIVE", "FAILED", "SUCCEEDED", "CANCELED", "SUCCEEDED_WITH_WARNINGS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The import_job_execution_status of this ImportDataAssetJobResult.
        :rtype: str
        """
        return self._import_job_execution_status

    @import_job_execution_status.setter
    def import_job_execution_status(self, import_job_execution_status):
        """
        Sets the import_job_execution_status of this ImportDataAssetJobResult.
        The status of the import job execution.


        :param import_job_execution_status: The import_job_execution_status of this ImportDataAssetJobResult.
        :type: str
        """
        allowed_values = ["CREATED", "IN_PROGRESS", "INACTIVE", "FAILED", "SUCCEEDED", "CANCELED", "SUCCEEDED_WITH_WARNINGS"]
        if not value_allowed_none_or_none_sentinel(import_job_execution_status, allowed_values):
            import_job_execution_status = 'UNKNOWN_ENUM_VALUE'
        self._import_job_execution_status = import_job_execution_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseSoftwareImageSummary(object):
    """
    The Database service supports the creation of database software images for use in creating and patching DB systems and databases.

    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see `Getting Started with Policies`__.

    For information about access control and compartments, see `Overview of the Identity Service`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm
    """

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the image_type property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "GRID_IMAGE"
    IMAGE_TYPE_GRID_IMAGE = "GRID_IMAGE"

    #: A constant which can be used with the image_type property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "DATABASE_IMAGE"
    IMAGE_TYPE_DATABASE_IMAGE = "DATABASE_IMAGE"

    #: A constant which can be used with the image_shape_family property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "VM_BM_SHAPE"
    IMAGE_SHAPE_FAMILY_VM_BM_SHAPE = "VM_BM_SHAPE"

    #: A constant which can be used with the image_shape_family property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "EXADATA_SHAPE"
    IMAGE_SHAPE_FAMILY_EXADATA_SHAPE = "EXADATA_SHAPE"

    #: A constant which can be used with the image_shape_family property of a DatabaseSoftwareImageSummary.
    #: This constant has a value of "EXACC_SHAPE"
    IMAGE_SHAPE_FAMILY_EXACC_SHAPE = "EXACC_SHAPE"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseSoftwareImageSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DatabaseSoftwareImageSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DatabaseSoftwareImageSummary.
        :type compartment_id: str

        :param database_version:
            The value to assign to the database_version property of this DatabaseSoftwareImageSummary.
        :type database_version: str

        :param display_name:
            The value to assign to the display_name property of this DatabaseSoftwareImageSummary.
        :type display_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DatabaseSoftwareImageSummary.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "DELETING", "DELETED", "FAILED", "TERMINATING", "TERMINATED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DatabaseSoftwareImageSummary.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this DatabaseSoftwareImageSummary.
        :type time_created: datetime

        :param image_type:
            The value to assign to the image_type property of this DatabaseSoftwareImageSummary.
            Allowed values for this property are: "GRID_IMAGE", "DATABASE_IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type image_type: str

        :param image_shape_family:
            The value to assign to the image_shape_family property of this DatabaseSoftwareImageSummary.
            Allowed values for this property are: "VM_BM_SHAPE", "EXADATA_SHAPE", "EXACC_SHAPE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type image_shape_family: str

        :param patch_set:
            The value to assign to the patch_set property of this DatabaseSoftwareImageSummary.
        :type patch_set: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DatabaseSoftwareImageSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DatabaseSoftwareImageSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param database_software_image_included_patches:
            The value to assign to the database_software_image_included_patches property of this DatabaseSoftwareImageSummary.
        :type database_software_image_included_patches: list[str]

        :param included_patches_summary:
            The value to assign to the included_patches_summary property of this DatabaseSoftwareImageSummary.
        :type included_patches_summary: str

        :param database_software_image_one_off_patches:
            The value to assign to the database_software_image_one_off_patches property of this DatabaseSoftwareImageSummary.
        :type database_software_image_one_off_patches: list[str]

        :param ls_inventory:
            The value to assign to the ls_inventory property of this DatabaseSoftwareImageSummary.
        :type ls_inventory: str

        :param is_upgrade_supported:
            The value to assign to the is_upgrade_supported property of this DatabaseSoftwareImageSummary.
        :type is_upgrade_supported: bool

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'database_version': 'str',
            'display_name': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'image_type': 'str',
            'image_shape_family': 'str',
            'patch_set': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'database_software_image_included_patches': 'list[str]',
            'included_patches_summary': 'str',
            'database_software_image_one_off_patches': 'list[str]',
            'ls_inventory': 'str',
            'is_upgrade_supported': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'database_version': 'databaseVersion',
            'display_name': 'displayName',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'image_type': 'imageType',
            'image_shape_family': 'imageShapeFamily',
            'patch_set': 'patchSet',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'database_software_image_included_patches': 'databaseSoftwareImageIncludedPatches',
            'included_patches_summary': 'includedPatchesSummary',
            'database_software_image_one_off_patches': 'databaseSoftwareImageOneOffPatches',
            'ls_inventory': 'lsInventory',
            'is_upgrade_supported': 'isUpgradeSupported'
        }

        self._id = None
        self._compartment_id = None
        self._database_version = None
        self._display_name = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._image_type = None
        self._image_shape_family = None
        self._patch_set = None
        self._freeform_tags = None
        self._defined_tags = None
        self._database_software_image_included_patches = None
        self._included_patches_summary = None
        self._database_software_image_one_off_patches = None
        self._ls_inventory = None
        self._is_upgrade_supported = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DatabaseSoftwareImageSummary.
        The `OCID`__ of the database software image.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DatabaseSoftwareImageSummary.
        The `OCID`__ of the database software image.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DatabaseSoftwareImageSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DatabaseSoftwareImageSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def database_version(self):
        """
        **[Required]** Gets the database_version of this DatabaseSoftwareImageSummary.
        The database version with which the database software image is to be built.


        :return: The database_version of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this DatabaseSoftwareImageSummary.
        The database version with which the database software image is to be built.


        :param database_version: The database_version of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._database_version = database_version

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this DatabaseSoftwareImageSummary.
        The user-friendly name for the database software image. The name does not have to be unique.


        :return: The display_name of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DatabaseSoftwareImageSummary.
        The user-friendly name for the database software image. The name does not have to be unique.


        :param display_name: The display_name of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DatabaseSoftwareImageSummary.
        The current state of the database software image.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "DELETING", "DELETED", "FAILED", "TERMINATING", "TERMINATED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DatabaseSoftwareImageSummary.
        The current state of the database software image.


        :param lifecycle_state: The lifecycle_state of this DatabaseSoftwareImageSummary.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "DELETING", "DELETED", "FAILED", "TERMINATING", "TERMINATED", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DatabaseSoftwareImageSummary.
        Detailed message for the lifecycle state.


        :return: The lifecycle_details of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DatabaseSoftwareImageSummary.
        Detailed message for the lifecycle state.


        :param lifecycle_details: The lifecycle_details of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DatabaseSoftwareImageSummary.
        The date and time the database software image was created.


        :return: The time_created of this DatabaseSoftwareImageSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DatabaseSoftwareImageSummary.
        The date and time the database software image was created.


        :param time_created: The time_created of this DatabaseSoftwareImageSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def image_type(self):
        """
        **[Required]** Gets the image_type of this DatabaseSoftwareImageSummary.
        The type of software image. Can be grid or database.

        Allowed values for this property are: "GRID_IMAGE", "DATABASE_IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The image_type of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._image_type

    @image_type.setter
    def image_type(self, image_type):
        """
        Sets the image_type of this DatabaseSoftwareImageSummary.
        The type of software image. Can be grid or database.


        :param image_type: The image_type of this DatabaseSoftwareImageSummary.
        :type: str
        """
        allowed_values = ["GRID_IMAGE", "DATABASE_IMAGE"]
        if not value_allowed_none_or_none_sentinel(image_type, allowed_values):
            image_type = 'UNKNOWN_ENUM_VALUE'
        self._image_type = image_type

    @property
    def image_shape_family(self):
        """
        **[Required]** Gets the image_shape_family of this DatabaseSoftwareImageSummary.
        To what shape the image is meant for.

        Allowed values for this property are: "VM_BM_SHAPE", "EXADATA_SHAPE", "EXACC_SHAPE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The image_shape_family of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._image_shape_family

    @image_shape_family.setter
    def image_shape_family(self, image_shape_family):
        """
        Sets the image_shape_family of this DatabaseSoftwareImageSummary.
        To what shape the image is meant for.


        :param image_shape_family: The image_shape_family of this DatabaseSoftwareImageSummary.
        :type: str
        """
        allowed_values = ["VM_BM_SHAPE", "EXADATA_SHAPE", "EXACC_SHAPE"]
        if not value_allowed_none_or_none_sentinel(image_shape_family, allowed_values):
            image_shape_family = 'UNKNOWN_ENUM_VALUE'
        self._image_shape_family = image_shape_family

    @property
    def patch_set(self):
        """
        **[Required]** Gets the patch_set of this DatabaseSoftwareImageSummary.
        The PSU or PBP or Release Updates. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :return: The patch_set of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._patch_set

    @patch_set.setter
    def patch_set(self, patch_set):
        """
        Sets the patch_set of this DatabaseSoftwareImageSummary.
        The PSU or PBP or Release Updates. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :param patch_set: The patch_set of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._patch_set = patch_set

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DatabaseSoftwareImageSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DatabaseSoftwareImageSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DatabaseSoftwareImageSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DatabaseSoftwareImageSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DatabaseSoftwareImageSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DatabaseSoftwareImageSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DatabaseSoftwareImageSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DatabaseSoftwareImageSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def database_software_image_included_patches(self):
        """
        Gets the database_software_image_included_patches of this DatabaseSoftwareImageSummary.
        List of one-off patches for Database Homes.


        :return: The database_software_image_included_patches of this DatabaseSoftwareImageSummary.
        :rtype: list[str]
        """
        return self._database_software_image_included_patches

    @database_software_image_included_patches.setter
    def database_software_image_included_patches(self, database_software_image_included_patches):
        """
        Sets the database_software_image_included_patches of this DatabaseSoftwareImageSummary.
        List of one-off patches for Database Homes.


        :param database_software_image_included_patches: The database_software_image_included_patches of this DatabaseSoftwareImageSummary.
        :type: list[str]
        """
        self._database_software_image_included_patches = database_software_image_included_patches

    @property
    def included_patches_summary(self):
        """
        Gets the included_patches_summary of this DatabaseSoftwareImageSummary.
        The patches included in the image and the version of the image


        :return: The included_patches_summary of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._included_patches_summary

    @included_patches_summary.setter
    def included_patches_summary(self, included_patches_summary):
        """
        Sets the included_patches_summary of this DatabaseSoftwareImageSummary.
        The patches included in the image and the version of the image


        :param included_patches_summary: The included_patches_summary of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._included_patches_summary = included_patches_summary

    @property
    def database_software_image_one_off_patches(self):
        """
        Gets the database_software_image_one_off_patches of this DatabaseSoftwareImageSummary.
        List of one-off patches for Database Homes.


        :return: The database_software_image_one_off_patches of this DatabaseSoftwareImageSummary.
        :rtype: list[str]
        """
        return self._database_software_image_one_off_patches

    @database_software_image_one_off_patches.setter
    def database_software_image_one_off_patches(self, database_software_image_one_off_patches):
        """
        Sets the database_software_image_one_off_patches of this DatabaseSoftwareImageSummary.
        List of one-off patches for Database Homes.


        :param database_software_image_one_off_patches: The database_software_image_one_off_patches of this DatabaseSoftwareImageSummary.
        :type: list[str]
        """
        self._database_software_image_one_off_patches = database_software_image_one_off_patches

    @property
    def ls_inventory(self):
        """
        Gets the ls_inventory of this DatabaseSoftwareImageSummary.
        output from lsinventory which will get passed as a string


        :return: The ls_inventory of this DatabaseSoftwareImageSummary.
        :rtype: str
        """
        return self._ls_inventory

    @ls_inventory.setter
    def ls_inventory(self, ls_inventory):
        """
        Sets the ls_inventory of this DatabaseSoftwareImageSummary.
        output from lsinventory which will get passed as a string


        :param ls_inventory: The ls_inventory of this DatabaseSoftwareImageSummary.
        :type: str
        """
        self._ls_inventory = ls_inventory

    @property
    def is_upgrade_supported(self):
        """
        Gets the is_upgrade_supported of this DatabaseSoftwareImageSummary.
        True if this Database software image is supported for Upgrade.


        :return: The is_upgrade_supported of this DatabaseSoftwareImageSummary.
        :rtype: bool
        """
        return self._is_upgrade_supported

    @is_upgrade_supported.setter
    def is_upgrade_supported(self, is_upgrade_supported):
        """
        Sets the is_upgrade_supported of this DatabaseSoftwareImageSummary.
        True if this Database software image is supported for Upgrade.


        :param is_upgrade_supported: The is_upgrade_supported of this DatabaseSoftwareImageSummary.
        :type: bool
        """
        self._is_upgrade_supported = is_upgrade_supported

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Connection(object):
    """
    The network connection results.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Connection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param address:
            The value to assign to the address property of this Connection.
        :type address: str

        :param port:
            The value to assign to the port property of this Connection.
        :type port: int

        """
        self.swagger_types = {
            'address': 'str',
            'port': 'int'
        }

        self.attribute_map = {
            'address': 'address',
            'port': 'port'
        }

        self._address = None
        self._port = None

    @property
    def address(self):
        """
        Gets the address of this Connection.
        The connection IP address.


        :return: The address of this Connection.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this Connection.
        The connection IP address.


        :param address: The address of this Connection.
        :type: str
        """
        self._address = address

    @property
    def port(self):
        """
        Gets the port of this Connection.
        The port.


        :return: The port of this Connection.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this Connection.
        The port.


        :param port: The port of this Connection.
        :type: int
        """
        self._port = port

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Plugin(object):
    """
    The agent plugin
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Plugin object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Plugin.
        :type name: str

        :param version:
            The value to assign to the version property of this Plugin.
        :type version: str

        :param status:
            The value to assign to the status property of this Plugin.
        :type status: str

        :param last_update_time:
            The value to assign to the last_update_time property of this Plugin.
        :type last_update_time: datetime

        :param message:
            The value to assign to the message property of this Plugin.
        :type message: str

        """
        self.swagger_types = {
            'name': 'str',
            'version': 'str',
            'status': 'str',
            'last_update_time': 'datetime',
            'message': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version',
            'status': 'status',
            'last_update_time': 'lastUpdateTime',
            'message': 'message'
        }

        self._name = None
        self._version = None
        self._status = None
        self._last_update_time = None
        self._message = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Plugin.
        The plugin name


        :return: The name of this Plugin.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Plugin.
        The plugin name


        :param name: The name of this Plugin.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        **[Required]** Gets the version of this Plugin.
        The plugin version


        :return: The version of this Plugin.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Plugin.
        The plugin version


        :param version: The version of this Plugin.
        :type: str
        """
        self._version = version

    @property
    def status(self):
        """
        **[Required]** Gets the status of this Plugin.
        The plugin status


        :return: The status of this Plugin.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Plugin.
        The plugin status


        :param status: The status of this Plugin.
        :type: str
        """
        self._status = status

    @property
    def last_update_time(self):
        """
        Gets the last_update_time of this Plugin.
        The last update time of the plugin


        :return: The last_update_time of this Plugin.
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """
        Sets the last_update_time of this Plugin.
        The last update time of the plugin


        :param last_update_time: The last_update_time of this Plugin.
        :type: datetime
        """
        self._last_update_time = last_update_time

    @property
    def message(self):
        """
        Gets the message of this Plugin.
        The optional message from the agent plugin


        :return: The message of this Plugin.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this Plugin.
        The optional message from the agent plugin


        :param message: The message of this Plugin.
        :type: str
        """
        self._message = message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
